wukong_easy_sdk library

WuKongIM Flutter EasySDK

A lightweight Flutter SDK for WuKongIM that enables real-time chat functionality.

Classes

ConnectResult
Result of a successful connection and authentication
DisconnectInfo
Information about a disconnection event
EventNotification
Event Notification Interface Represents a custom event notification from the server
Message
Received message from the server
MessageHeader
Header information for messages
MessagePayload
Message payload for sending messages
ReconnectingInfo
Information about a reconnection attempt
SendResult
Result of sending a message
WuKongChannelType
WuKong Channel Type Enum based on WuKongIM protocol
WuKongConfig
Configuration class for WuKong SDK
WuKongEasySDK
WuKong Easy SDK
WuKongError
WuKong SDK Error
WuKongReasonCode
WuKong Reason Code

Enums

WuKongDeviceFlag
WuKong Device Flag Enum
WuKongErrorCode
WuKong Error Code Enum
WuKongEvent
WuKong SDK Event Types

Typedefs

WuKongEventListener<T> = void Function(T data)
Type definition for event listeners

Exceptions / Errors

WuKongAuthenticationException
Exception thrown when authentication fails
WuKongConfigurationException
Exception thrown when the configuration is invalid
WuKongConnectionTimeoutException
Exception thrown when connection times out
WuKongException
Base exception class for WuKong SDK
WuKongInvalidChannelException
Exception thrown when trying to send a message to an invalid channel
WuKongMessageTooLargeException
Exception thrown when trying to send a message that is too large
WuKongNetworkException
Exception thrown when there's a network error
WuKongNotConnectedException
Exception thrown when trying to perform an operation while not connected
WuKongProtocolException
Exception thrown when there's a protocol error